@@ -4,7 +4,9 @@ from .graph import SensorGraph
 from .model import DeviceModel
 from .sensor_log import SensorLog
 from .slot import SlotIdentifier
+from .node import SGNode
+from .compiler import compile_sgf
+
 
 __all__ = ['DeviceModel', 'DataStream', 'SensorGraph', 'DataStreamSelector',
-           'StreamEmptyError',  'SensorLog', 'SlotIdentifier']
-
+           'StreamEmptyError',  'SensorLog', 'SlotIdentifier', 'SGNode', 'compile_sgf']
